@@ -8,7 +8,7 @@ require Exporter;
 use warnings;
 use strict;
 use Carp;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 require XSLoader;
 XSLoader::load ('Image::PNG::QRCode', $VERSION);
 
@@ -67,7 +67,7 @@ sub qrpng
     }
     qrpng_internal (\%options);
     if ($r) {
-	return ${$options{png_data}};
+	return $options{png_data};
     }
     elsif ($s) {
 	${$options{out}} = $options{png_data};
